@@ -1,10 +1,6 @@
 use std::io::{self, Write};
-use std::sync::atomic::{AtomicBool, Ordering};
-use std::sync::Arc;
 
-use anyhow::{anyhow, bail, Result};
-use crossterm::{cursor, terminal, ExecutableCommand};
-use opencv::{core, imgproc, prelude::*, videoio};
+use anyhow::{anyhow, Result};
 use output::PrinterFactory;
 use resize::ResizerFactory;
 use structopt::StructOpt as _;
@@ -12,6 +8,8 @@ use structopt::StructOpt as _;
 mod cli;
 mod output;
 mod resize;
+
+#[cfg(feature = "opencv")]
 mod util;
 
 const USAGE: &str = "\
@@ -21,7 +19,32 @@ USAGE:
 For more information try --help\
 ";
 
+fn restore_cursor() -> Result<()> {
+    print!("\x1b[?25h\x1b[0m");
+    io::stdout().flush()?;
+    Ok(())
+}
+
+#[cfg(feature = "opencv")]
 fn run(opt: cli::Opt) -> Result<()> {
+    use std::sync::atomic::{AtomicBool, Ordering};
+    use std::sync::Arc;
+
+    use anyhow::bail;
+    use crossterm::{cursor, terminal, ExecutableCommand};
+    use opencv::{core, imgproc, prelude::*, videoio};
+
+    if opt.build_info {
+        println!("{} {}\n", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
+        print!("Built with OpenCV");
+        println!("{}", core::get_build_information().unwrap());
+        return Ok(());
+    }
+
+    if !opt.verbose {
+        util::suppress_stderr()
+    }
+
     let path = opt.path.ok_or_else(|| anyhow!(USAGE))?;
     let mut cam = match path.parse() {
         #[cfg(feature = "opencv-32")]
@@ -50,8 +73,8 @@ fn run(opt: cli::Opt) -> Result<()> {
 
     let out = io::stdout();
     let mut out = io::BufWriter::new(out.lock());
-    let resizer = ResizerFactory::create(&opt.protrude, &opt.flat);
-    let printer = PrinterFactory::create(&opt.flat);
+    let resizer = ResizerFactory::create(opt.protrude, opt.flat);
+    let printer = PrinterFactory::create(opt.flat);
 
     let mut first_frame = true;
     while !killed.load(Ordering::SeqCst) {
@@ -80,24 +103,52 @@ fn run(opt: cli::Opt) -> Result<()> {
     }
     out.flush()?;
 
-    print!("\x1b[?25h\x1b[0m");
-    io::stdout().flush()?;
+    restore_cursor()?;
     Ok(())
 }
 
-fn main() {
-    let opt = cli::Opt::from_args();
+#[cfg(not(feature = "opencv"))]
+fn run(opt: cli::Opt) -> Result<()> {
     if opt.build_info {
-        println!("{}", core::get_build_information().unwrap());
-        return;
+        println!("{} {}\n", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
+        println!("Built without OpenCV");
+        return Ok(());
     }
 
-    if !opt.verbose {
-        util::suppress_stderr()
+    let path = opt.path.ok_or_else(|| anyhow!(USAGE))?;
+    let mut img = image::open(path)?;
+
+    let out = io::stdout();
+    let mut out = io::BufWriter::new(out.lock());
+    let resizer = ResizerFactory::create(opt.protrude, opt.flat);
+    let printer = PrinterFactory::create(opt.flat);
+
+    if opt.rotate {
+        img = img.rotate270();
     }
 
+    let resized = resizer.resize_img(&img)?;
+
+    print!("\x1b[?25l");
+    ctrlc::set_handler(|| {
+        restore_cursor().unwrap();
+    })?;
+    printer.print_img(&resized, &mut out)?;
+    out.flush()?;
+
+    restore_cursor()?;
+    Ok(())
+}
+
+fn main() -> Result<()> {
+    let opt = cli::Opt::from_args();
+
     if let Err(e) = run(opt) {
         println!("{:?}", e);
+        restore_cursor()?;
         std::process::exit(1);
     }
+
+    restore_cursor()?;
+    Ok(())
 }
